Contributing to Clant
=====================

Feel free to submit patches to Clant that make it work better for you.  Support
for reasonable new features or other similar linting tools is welcome, but
please try to preserve the idea that Clant should be easy to use, and running
it without arguments should do something reasonable by default.

The code is formatted with `black -l 79` and is clean with both `flake8` and
`pylint`.  Try not to add any suppressions if at all possible.

Happy hacking.
